summaryrefslogtreecommitdiffstats
path: root/main
diff options
context:
space:
mode:
Diffstat (limited to 'main')
-rw-r--r--main/app_icon.pngbin3770 -> 5300 bytes
-rw-r--r--main/main.cpp32
-rw-r--r--main/main.h6
-rw-r--r--main/main_timer_sync.cpp6
-rw-r--r--main/main_timer_sync.h6
-rw-r--r--main/performance.cpp6
-rw-r--r--main/performance.h6
-rw-r--r--main/splash.pngbin14766 -> 15083 bytes
-rw-r--r--main/steam_tracker.cpp6
-rw-r--r--main/steam_tracker.h8
10 files changed, 46 insertions, 30 deletions
diff --git a/main/app_icon.png b/main/app_icon.png
index cf31af18a4..6d01c312bb 100644
--- a/main/app_icon.png
+++ b/main/app_icon.png
Binary files differ
diff --git a/main/main.h b/main/main.h
index 6dd2ff7d7a..1fc5837443 100644
--- a/main/main.h
+++ b/main/main.h
@@ -2,9 +2,11 @@
/* main.h */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
diff --git a/main/main_timer_sync.cpp b/main/main_timer_sync.cpp
index 569930d427..3697485b85 100644
--- a/main/main_timer_sync.cpp
+++ b/main/main_timer_sync.cpp
@@ -2,9 +2,11 @@
/* main_timer_sync.cpp */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
diff --git a/main/main_timer_sync.h b/main/main_timer_sync.h
index d8b5d4a02d..f78a47d054 100644
--- a/main/main_timer_sync.h
+++ b/main/main_timer_sync.h
@@ -2,9 +2,11 @@
/* main_timer_sync.h */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
diff --git a/main/performance.cpp b/main/performance.cpp
index 398511995b..909dcb6ec3 100644
--- a/main/performance.cpp
+++ b/main/performance.cpp
@@ -2,9 +2,11 @@
/* performance.cpp */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
diff --git a/main/performance.h b/main/performance.h
index e88bdcb337..68dc8c1e49 100644
--- a/main/performance.h
+++ b/main/performance.h
@@ -2,9 +2,11 @@
/* performance.h */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
diff --git a/main/splash.png b/main/splash.png
index 7bddd4325a..48dd1dfe94 100644
--- a/main/splash.png
+++ b/main/splash.png
Binary files differ
diff --git a/main/steam_tracker.cpp b/main/steam_tracker.cpp
index 4c90b5d864..d9412e97b6 100644
--- a/main/steam_tracker.cpp
+++ b/main/steam_tracker.cpp
@@ -2,9 +2,11 @@
/* steam_tracker.cpp */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
diff --git a/main/steam_tracker.h b/main/steam_tracker.h
index 535b81b950..4f28dc4581 100644
--- a/main/steam_tracker.h
+++ b/main/steam_tracker.h
@@ -2,9 +2,11 @@
/* steam_tracker.h */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
@@ -36,7 +38,7 @@
#include "core/os/os.h"
// SteamTracker is used to load SteamAPI dynamic library and initialize
-// the interface, this notifies Steam that Godot editor is running and
+// the interface, this notifies Steam that Redot editor is running and
// allow tracking of the usage time of child instances of the engine
// (e.g., opened projects).
//
diff --git a/main/main.cpp b/main/main.cpp
index 123114ce8d..72856dd3e2 100644
--- a/main/main.cpp
+++ b/main/main.cpp
@@ -2,9 +2,11 @@
/* main.cpp */
/**************************************************************************/
/* This file is part of: */
-/* GODOT ENGINE */
-/* https://godotengine.org */
+/* REDOT ENGINE */
+/* https://redotengine.org */
/**************************************************************************/
+/* Copyright (c) 2024-present Redot Engine contributors */
+/* (see REDOT_AUTHORS.md) */
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur. */
/* */
@@ -515,7 +517,7 @@ void Main::print_help_option(const char *p_option, const char *p_description, CL
void Main::print_help(const char *p_binary) {
print_header(true);
print_help_copyright("Free and open source software under the terms of the MIT license.");
- print_help_copyright("(c) 2014-present Godot Engine contributors. (c) 2007-present Juan Linietsky, Ariel Manzur.");
+ print_help_copyright("(c) 2024-present Redot Engine contributors. (c) 2014-present Godot Engine contributors. (c) 2007-present Juan Linietsky, Ariel Manzur.");
print_help_title("Usage");
OS::get_singleton()->print(" %s \u001b[96m[options] [path to scene or \"project.godot\" file]\u001b[0m\n", p_binary);
@@ -673,9 +675,9 @@ void Main::print_help(const char *p_binary) {
#ifndef DISABLE_DEPRECATED
// Commands are long; split the description to a second line.
print_help_option("--convert-3to4 ", "\n", CLI_OPTION_AVAILABILITY_HIDDEN);
- print_help_option(" [max_file_kb] [max_line_size]", "Converts project from Godot 3.x to Godot 4.x.\n", CLI_OPTION_AVAILABILITY_EDITOR);
+ print_help_option(" [max_file_kb] [max_line_size]", "Converts project from Redot 3.x to Redot 4.x.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("--validate-conversion-3to4 ", "\n", CLI_OPTION_AVAILABILITY_HIDDEN);
- print_help_option(" [max_file_kb] [max_line_size]", "Shows what elements will be renamed when converting project from Godot 3.x to Godot 4.x.\n", CLI_OPTION_AVAILABILITY_EDITOR);
+ print_help_option(" [max_file_kb] [max_line_size]", "Shows what elements will be renamed when converting project from Redot 3.x to Redot 4.x.\n", CLI_OPTION_AVAILABILITY_EDITOR);
#endif // DISABLE_DEPRECATED
print_help_option("--doctool [path]", "Dump the engine API reference to the given <path> (defaults to current directory) in XML format, merging if existing files are found.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("--no-docbase", "Disallow dumping the base types (used with --doctool).\n", CLI_OPTION_AVAILABILITY_EDITOR);
@@ -685,8 +687,8 @@ void Main::print_help(const char *p_binary) {
#endif
print_help_option("--build-solutions", "Build the scripting solutions (e.g. for C# projects). Implies --editor and requires a valid project to edit.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("--dump-gdextension-interface", "Generate a GDExtension header file \"gdextension_interface.h\" in the current folder. This file is the base file required to implement a GDExtension.\n", CLI_OPTION_AVAILABILITY_EDITOR);
- print_help_option("--dump-extension-api", "Generate a JSON dump of the Godot API for GDExtension bindings named \"extension_api.json\" in the current folder.\n", CLI_OPTION_AVAILABILITY_EDITOR);
- print_help_option("--dump-extension-api-with-docs", "Generate JSON dump of the Godot API like the previous option, but including documentation.\n", CLI_OPTION_AVAILABILITY_EDITOR);
+ print_help_option("--dump-extension-api", "Generate a JSON dump of the Redot API for GDExtension bindings named \"extension_api.json\" in the current folder.\n", CLI_OPTION_AVAILABILITY_EDITOR);
+ print_help_option("--dump-extension-api-with-docs", "Generate JSON dump of the Redot API like the previous option, but including documentation.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("--validate-extension-api <path>", "Validate an extension API file dumped (with one of the two previous options) from a previous version of the engine to ensure API compatibility.\n", CLI_OPTION_AVAILABILITY_EDITOR);
print_help_option("", "If incompatibilities or errors are detected, the exit code will be non-zero.\n");
print_help_option("--benchmark", "Benchmark the run time and print it to console.\n", CLI_OPTION_AVAILABILITY_EDITOR);
@@ -901,8 +903,8 @@ int Main::test_entrypoint(int argc, char *argv[], bool &tests_need_run) {
return status;
#else
ERR_PRINT(
- "`--test` was specified on the command line, but this Godot binary was compiled without support for unit tests. Aborting.\n"
- "To be able to run unit tests, use the `tests=yes` SCons option when compiling Godot.\n");
+ "`--test` was specified on the command line, but this Redot binary was compiled without support for unit tests. Aborting.\n"
+ "To be able to run unit tests, use the `tests=yes` SCons option when compiling Redot.\n");
return EXIT_FAILURE;
#endif
}
@@ -1046,7 +1048,7 @@ Error Main::setup(const char *execpath, int argc, char *argv[], bool p_second_ph
#ifdef MACOS_ENABLED
// Ignore the process serial number argument passed by macOS Gatekeeper.
// Otherwise, Godot would try to open a non-existent project on the first start and abort.
if (arg.begins_with("-psn_")) {
I = N;
continue;
@@ -1512,7 +1514,7 @@ Error Main::setup(const char *execpath, int argc, char *argv[], bool p_second_ph
}
#ifndef DISABLE_DEPRECATED
} else if (arg == "--export") { // For users used to 3.x syntax.
- OS::get_singleton()->print("The Godot 3 --export option was changed to more explicit --export-release / --export-debug / --export-pack options.\nSee the --help output for details.\n");
+ OS::get_singleton()->print("The Redot 3 --export option was changed to more explicit --export-release / --export-debug / --export-pack options.\nSee the --help output for details.\n");
goto error;
} else if (arg == "--convert-3to4") {
// Actually handling is done in start().
@@ -3190,7 +3192,7 @@ Error Main::setup2(bool p_show_boot_logo) {
DisplayServer::get_singleton()->window_set_flag(DisplayServer::WINDOW_FLAG_ALWAYS_ON_TOP, true);
}
- Color clear = GLOBAL_DEF_BASIC("rendering/environment/defaults/default_clear_color", Color(0.3, 0.3, 0.3));
+ Color clear = GLOBAL_DEF_BASIC("rendering/environment/defaults/default_clear_color", Color(0.128, 0.128, 0.128));
RenderingServer::get_singleton()->set_default_clear_color(clear);
if (p_show_boot_logo) {
@@ -3592,7 +3594,7 @@ int Main::start() {
E->get().ends_with(".res") ||
E->get().ends_with(".tres")) {
// Only consider the positional argument to be a scene path if it ends with
// a file extension associated with Godot scenes. This makes it possible
// for projects to parse command-line arguments for custom CLI arguments
// or other file extensions without trouble. This can be used to implement
// "drag-and-drop onto executable" logic, which can prove helpful
@@ -3687,7 +3689,7 @@ int Main::start() {
// Ensure that doctool is running in the root dir, but only if
// user did not manually specify a path as argument.
if (doc_tool_implicit_cwd) {
- ERR_FAIL_COND_V_MSG(!da->dir_exists("doc"), EXIT_FAILURE, "--doctool must be run from the Godot repository's root folder, or specify a path that points there.");
+ ERR_FAIL_COND_V_MSG(!da->dir_exists("doc"), EXIT_FAILURE, "--doctool must be run from the Redot repository's root folder, or specify a path that points there.");
}
}
@@ -3735,7 +3737,7 @@ int Main::start() {
}
}
// For GDExtension docs, use a path that is compatible with Godot modules.
String index_path = gdextension_docs ? doc_tool_path.path_join("doc_classes") : doc_tool_path.path_join("doc/classes");
// Create the main documentation directory if it doesn't exist
Ref<DirAccess> da = DirAccess::create_for_path(index_path);
@@ -1046,7 +1048,7 @@ Error Main::setup(const char *execpath, int argc, char *argv[], bool p_second_ph
#ifdef MACOS_ENABLED
// Ignore the process serial number argument passed by macOS Gatekeeper.
- // Otherwise, Godot would try to open a non-existent project on the first start and abort.
+ // Otherwise, Redot would try to open a non-existent project on the first start and abort.
if (arg.begins_with("-psn_")) {
I = N;
@@ -3592,7 +3594,7 @@ int Main::start() {
E->get().ends_with(".tres")) {
// Only consider the positional argument to be a scene path if it ends with
- // a file extension associated with Godot scenes. This makes it possible
+ // a file extension associated with Redot scenes. This makes it possible
// for projects to parse command-line arguments for custom CLI arguments
// or other file extensions without trouble. This can be used to implement
@@ -3735,7 +3737,7 @@ int Main::start() {
}
}
- // For GDExtension docs, use a path that is compatible with Godot modules.
+ // For GDExtension docs, use a path that is compatible with Redot modules.
String index_path = gdextension_docs ? doc_tool_path.path_join("doc_classes") : doc_tool_path.path_join("doc/classes");
// Create the main documentation directory if it doesn't exist